@@ -62,14 +62,14 @@ def html_secure(text):
     return re.sub('<', '&#60;', str(text))
 
 
-def html_link(link, text):
-    return '<a href="' + str(link) + '">' + str(text) + '</a>'
-
-
 def time_now():
     return int(datetime.now().timestamp())
 
 
+def html_link(link, text):
+    return '<a href="' + str(link) + '">' + str(text) + '</a>'
+
+
 def get_me_dict(token):
     me = str(telebot.TeleBot(token).get_me())
     return literal_eval(me)
@@ -82,6 +82,15 @@ def append_values(array, values):
     return array
 
 
+def environmental_files():
+    directory = os.listdir('.')
+    for key in os.environ.keys():
+        if key.endswith('.json') and key not in directory:
+            file = open(key, 'w')
+            file.write(os.environ.get(key))
+            file.close()
+
+
 def chunks(array, separate):
     separated = []
     d, r = divmod(len(array), separate)
